==> react-router-bootstrap-0.4.0.tgz: package/lib/RouteToMixin.js <==
var RESERVED_PROPS, React, RouteToMixin, getUnreservedProps, isLeftClick, isModifiedEvent, makeHref, mergeProperties, transitionTo, withoutProperties;

React = require('react');

makeHref = require('react-router/modules/helpers/makeHref');

transitionTo = require('react-router/modules/helpers/transitionTo');

withoutProperties = require('react-router/modules/helpers/withoutProperties');

mergeProperties = require('react-router/modules/helpers/mergeProperties');

RESERVED_PROPS = {
  to: true,
  className: true,
  activeClassName: true,
  query: true,
  children: true
};

RouteToMixin = {
  statics: {
    getUnreservedProps: getUnreservedProps
  },
  propTypes: {
    to: React.PropTypes.string.isRequired,
    query: React.PropTypes.object
  },
  getParams: function() {
    return getUnreservedProps(this.props, this.additionalReservedProps);
  },
  getHref: function() {
    return makeHref(this.props.to, this.getParams(), this.props.query);
  },
  handleRouteTo: function(event) {
    if (isModifiedEvent(event) || !isLeftClick(event)) {
      return;
    }
    event.preventDefault();
    return transitionTo(this.props.to, this.getParams(), this.props.query);
  }
};

isLeftClick = function(event) {
  return event.button === 0;
};

isModifiedEvent = function(event) {
  return !!(event.metaKey || event.altKey || event.ctrlKey || event.shiftKey);
};

getUnreservedProps = function(props, additionalReservedProps) {
  var reservedProps;
  if (additionalReservedProps) {
    reservedProps = mergeProperties({}, RESERVED_PROPS);
    reservedProps = mergeProperties(reservedProps, additionalReservedProps);
  } else {
    reservedProps = RESERVED_PROPS;
  }
  return withoutProperties(props, reservedProps);
};

module.exports = RouteToMixin;

==> react-router-bootstrap-0.4.4.tgz: package/lib/RouteToMixin.js <==
var RESERVED_PROPS, React, RouteToMixin, getUnreservedProps, isLeftClick, isModifiedEvent, makeHref, mergeProperties, transitionTo, withoutProperties;

React = require('react');

makeHref = require('react-router/modules/helpers/makeHref');

transitionTo = require('react-router/modules/helpers/transitionTo');

withoutProperties = require('react-router/modules/helpers/withoutProperties');

mergeProperties = require('react-router/modules/helpers/mergeProperties');

RESERVED_PROPS = {
  to: true,
  className: true,
  activeClassName: true,
  query: true,
  children: true
};

RouteToMixin = {
  getUnreservedProps: getUnreservedProps,
  propTypes: {
    to: React.PropTypes.string.isRequired,
    query: React.PropTypes.object
  },
  getParams: function() {
    return getUnreservedProps(this.props, this.additionalReservedProps);
  },
  getHref: function() {
    return makeHref(this.props.to, this.getParams(), this.props.query);
  },
  handleRouteTo: function(event) {
    if (isModifiedEvent(event) || !isLeftClick(event)) {
      return;
    }
    event.preventDefault();
    return transitionTo(this.props.to, this.getParams(), this.props.query);
  }
};

isLeftClick = function(event) {
  return event.button === 0;
};

isModifiedEvent = function(event) {
  return !!(event.metaKey || event.altKey || event.ctrlKey || event.shiftKey);
};

getUnreservedProps = function(props, additionalReservedProps) {
  var reservedProps;
  if (additionalReservedProps) {
    reservedProps = mergeProperties({}, RESERVED_PROPS);
    reservedProps = mergeProperties(reservedProps, additionalReservedProps);
  } else {
    reservedProps = RESERVED_PROPS;
  }
  return withoutProperties(props, reservedProps);
};

module.exports = RouteToMixin;
